package com.hzya.frame.plugin.ht.service.impl;

import cn.hutool.core.lang.Assert;
import cn.hutool.http.HttpRequest;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.dynamic.datasource.annotation.DS;
import com.hzya.frame.basedao.service.impl.BaseService;
import com.hzya.frame.plugin.ht.dao.IApplyInvoiceDao;
import com.hzya.frame.plugin.ht.entity.ApplyInvoiceEntity;
import com.hzya.frame.plugin.ht.service.IApplyInvoiceService;
import com.hzya.frame.seeyon.util.OARestUtil;
import com.hzya.frame.web.exception.BaseSystemException;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @Description
 * @Author xiangerlin
 * @Date 2025/6/21 17:56
 **/
@Service(value = "applyInvoiceServiceImpl")
public class ApplyInvoiceServiceImpl extends BaseService<ApplyInvoiceEntity,String> implements IApplyInvoiceService {

    private IApplyInvoiceDao applyInvoiceDao;

    @Autowired
    public void setApplyInvoiceDao(IApplyInvoiceDao dao) {
        this.applyInvoiceDao = dao;
        this.dao = dao;
    }
    @Value("${zt.url}")
    private String interfaceUrl;




    /**
     * 查询待办信息
     *
     * @param entity
     * @return
     * @throws BaseSystemException
     */
    @DS("entity.dataSourceCode")
    @Override
    public ApplyInvoiceEntity queryAffair(ApplyInvoiceEntity entity) throws BaseSystemException {
        List<ApplyInvoiceEntity> queryList = applyInvoiceDao.queryList(entity, "com.hzya.frame.plugin.ht.dao.impl.ApplyInvoiceDaoImpl.entity_list_affair");
        if (CollectionUtils.isNotEmpty(queryList)){
            if (queryList.size() > 1){
                throw new BaseSystemException("数据异常，查询到多条待办数据"+entity.getId());
            }
            return queryList.get(0);
        }
        return null;
    }

    /**
     * 流程回退参数组装
     *
     * @param workitemId
     * @param content
     * @return
     */
    @Override
    public String stepBackValueOf(String workitemId, String content) {
        Assert.notEmpty(workitemId,"流程回退时workitemId 必填");
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("appName", "collaboration");
        jsonObject.put("workitemId", workitemId);

        JSONObject commentDeal = new JSONObject();
        commentDeal.put("attitude", "1");//1表示已阅
        commentDeal.put("content", content);

        JSONObject data = new JSONObject();
        data.put("isWFTrace", "0");
        data.put("comment_deal", commentDeal);

        jsonObject.put("data", data);
        return jsonObject.toJSONString();
    }

    /**
     * 流程结束参数组装
     *
     * @param workitemId
     * @param content
     * @return
     */
    @Override
    public String finishValueOf(String workitemId, String content) {
        Assert.notEmpty(workitemId,"流程回退时workitemId 必填");
        JSONObject json = new JSONObject();
        json.put("appName", "collaboration");
        json.put("workitemId", workitemId);

        JSONObject data = new JSONObject();
        data.put("submitType", "1");

        JSONObject commentDeal = new JSONObject();
        commentDeal.put("attitude", "2");//2表示同意
        commentDeal.put("content", content);
        data.put("comment_deal", commentDeal);
        json.put("data", data);
        return json.toJSONString();
    }

    /**
     * 流程处理
     *
     * @param param
     * @param apiCode
     * @return
     */
    @Override
    public String process(String param, String apiCode) {
        Assert.notEmpty(param,"流程处理时参数不能为空");
        Assert.notEmpty(apiCode,"apiCode不能为空");
        logger.info("准备提交或退回流程:{},{}",apiCode,param);
        String token = OARestUtil.getToken("hzya", "8000590001");
        String result = HttpRequest.post(interfaceUrl)
                .header("appId", "800059")//OA应用
                .header("apiCode", apiCode)//流程提交/回退接口
                .header("token", token)//token
                .header("publicKey", "ZJYAWb7lhAUTYqekPkU+uHJv1/ObJxb7dT7sD8HPRDGAgyhCe7eDIk+3zDUT+v578prj")//中台公钥
                .header("secretKey", "fviZnLBsQUAGF8w8FSOdJi7XlIm/XAZclMxRagDLfTyJFlvnIBF3w66Hrpfzs8cYj3JzOP8MtA1LSGvL+2BWG8c/o7DKi92S4mr3zcGearA=")//中台密钥
                .body(param)//表单内容
                .timeout(30000)//超时，毫秒
                .execute().body();
        return result;
    }
}
